# ウィナス採用サイトプロジェクト

## 📝 プロジェクトの概要

Udemyで学んだReactの知識を活かして、既存の採用サイトをリニューアルする25卒研修プロジェクト。
レトロな見た目から最新のデザインへ、基本的なReactの機能実装からパフォーマンスチューニングまで、
実践的なスキルを身につけることを目的としています。

## 🚀 技術スタック

- **フロントエンド**
  - React 18.2.0 - モダンなUI構築
  - React Router 6.4.0 - シングルページアプリケーションのルーティング
  - TailwindCSS 2.2.19 - スタイリング
  - @react-midi/hooks 2.0.1 - MIDI音楽の再生

- **開発ツール**
  - react-scripts 4.0.3 - 開発環境の構築
  - Babel - 最新のJavaScript機能のサポート

## 📁 プロジェクト構造の詳細

```
src/
├── components/          # 再利用可能なコンポーネント
│   ├── common/         # 共通コンポーネント
│   │   ├── BlinkingText/  # 点滅テキストコンポーネント
│   │   └── Layout/        # レイアウトコンポーネント
│   └── features/       # 機能別コンポーネント
│       ├── Popup/      # ポップアップ通知
│       └── Blog/       # ブログ関連
├── styles/             # スタイル定義
│   ├── base/          # ベーススタイル
│   └── themes/        # テーマ設定
└── pages/             # ページコンポーネント
```

## 💻 開発環境のセットアップ

### 前提条件
- Node.js (v14以上)
- npm (v6以上)

### インストール手順

1. **リポジトリのクローン**
```bash
git clone https://github.com/yourusername/winas-fake-corp.git
cd winas-fake-corp
```

2. **依存パッケージのインストール**
```bash
npm install
```

3. **開発サーバーの起動**
```bash
npm start
```

## 🎨 デザインガイドライン

### カラーパレット
- Primary: #008080 (Windows 95風のティール)
- Secondary: #c0c0c0 (クラシックなグレー)
- Accent: #000080 (ネイビーブルー)

### タイポグラフィ
- 基本フォント: "MS Sans Serif", Arial, sans-serif
- 見出しサイズ: 16px
- 本文サイズ: 14px

## 🔧 コーディング規約

### JavaScript/React
- コンポーネントはPascalCase
- 変数・関数名はcamelCase
- インデントは2スペース
- セミコロン必須

### CSS
- BEM命名規則を採用
- CSSモジュールを使用
- メディアクエリは mobile-first

## 📚 主要コンポーネント

### Layout
- 共通レイアウトを提供
- ナビゲーションバーを含む
- Windows 95風のデザイン

### Popup
- 訪問者への通知表示
- セッションごとに1回のみ表示
- アニメーション効果付き

## 🚀 デプロイ

```bash
# プロダクションビルドの生成
npm run build

# ビルドファイルは ./build に生成されます
```

## 🤝 コントリビューション

1. このリポジトリをフォーク
2. 機能ブランチを作成 (`git checkout -b feature/amazing-feature`)
3. 変更をコミット (`git commit -m 'Add amazing feature'`)
4. ブランチをプッシュ (`git push origin feature/amazing-feature`)
5. プルリクエストを作成


## 📫 サポート

質問や提案がありましたら、伊藤さん　or　先輩たちに聞いてくださいー！


